@@ -1,6 +1,8 @@
 import logging
 
 from .beatsaver import BeatSaver
+from .beatsaverapi import BeatSaverAPI
+from .beatsaver_provider import BeatSaverProvider
 from .errors import *
 from .models import *
 
