@@ -1,9 +1,10 @@
-from enum import Enum
+from .base_enum import BaseEnum
 
 
-class Difficulty(Enum):
+class Difficulty(BaseEnum):
     EASY = "Easy"
     NORMAL = "Normal"
     HARD = "Hard"
     EXPERT = "Expert"
     EXPERT_PLUS = "ExpertPlus"
+    UNKNOWN = "Unknown"
