@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import *
 
 from dataclasses_json import dataclass_json
 
@@ -10,8 +11,8 @@ from .user_detail import UserDetail
 @dataclass_json
 @dataclass
 class MapTestplay:
-    created_at: datetime = datetime_field("createdAt")
-    feedback: str = default()
-    feedback_at: datetime = datetime_field("feedbackAt")
+    feedback: Optional[str] = default()
+    video: Optional[str] = default()
     user: UserDetail = default()
-    video: str = default()
+    created_at: datetime = datetime_field("createdAt")
+    feedback_at: Optional[datetime] = datetime_field("feedbackAt")
