@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import *
 
 from dataclasses_json import dataclass_json
 
@@ -10,13 +11,13 @@ from .user_diff_stats import UserDiffStats
 @dataclass_json
 @dataclass
 class UserStats:
-    avg_bpm: float = default("avgBpm")
-    avg_duration: float = default("avgDuration")
-    avg_score: float = default("avgScore")
-    diff_stats: UserDiffStats = default("diffStats")
-    first_upload: datetime = datetime_field("firstUpload")
-    last_upload: datetime = datetime_field("lastUpload")
-    ranked_maps: int = default("rankedMaps")
+    total_upvotes: int = default("totalUpvotes")
     total_downvotes: int = default("totalDownvotes")
     total_maps: int = default("totalMaps")
-    total_upvotes: int = default("totalUpvotes")
+    ranked_maps: int = default("rankedMaps")
+    avg_bpm: float = default("avgBpm")
+    avg_score: float = default("avgScore")
+    avg_duration: float = default("avgDuration")
+    first_upload: Optional[datetime] = datetime_field("firstUpload")
+    last_upload: Optional[datetime] = datetime_field("lastUpload")
+    diff_stats: Optional[UserDiffStats] = default("diffStats")
